
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.008.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Catmandu modules to work with the Web Of Science web services",
  "dist_author" => [
    "Nicolas Steenlant <nicolas.steenlant\@ugent.be>"
  ],
  "dist_name" => "Catmandu-WoS",
  "dist_version" => "0.02",
  "license" => "perl",
  "module_name" => "Catmandu::WoS",
  "recursive_test_files" => 1,
  "requires" => {
    "Catmandu" => "1.0507",
    "MIME::Base64" => 0,
    "XML::Compile::SOAP11" => 0,
    "XML::Compile::Transport::SOAPHTTP" => 0,
    "XML::Compile::WSDL11" => "3.06",
    "XML::LibXML::Simple" => 0,
    "namespace::clean" => 0,
    "perl" => "5.008005"
  },
  "test_requires" => {
    "Test::More" => "0.96"
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.28",
  "Test::More" => "0.96"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
