package Catmandu::WoS;

use Catmandu::Sane;

our $VERSION = '0.02';

1;

__END__

=encoding utf-8

=head1 NAME

Catmandu::WoS - Catmandu modules to work with the Web Of Science web services

=head1 MODULES

=over

=item * L<Catmandu::Importer::WoS>

=back

=head1 AUTHOR

Nicolas Steenlant E<lt>nicolas.steenlant@ugent.beE<gt>

=head1 COPYRIGHT

Copyright 2017- Nicolas Steenlant

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
